.. currentmodule:: pycvcam

Distort and Undistort Images
==================================

.. autosummary::
   :toctree: ../_autosummary/

   distort_image
   undistort_image

Examples
--------

See a complete example in the gallery: :ref:`sphx_glr__gallery_distorting_image.py`. 

